#! perl -w
#
#####################################################
#
#  This is a quickie Perl prog which takes the subcircuit file LTC.lib
#  distributed with Linear Tech's SwitcherCADIII, blows it apart,
#  and creates a set of individual subckt files compatible with 
#  the gEDA spice-SDB netlister.  
#
#  The output files created are named after the name of the
#  model itself; the suffix .cir is appended to the subckt
#  name to create the file name.
#
#  I wrote this quickie prog in order to populate my models/spice
#  directory with spice models quickly.
#
#  Usage:  perl MakeLTCSubckts.pl < LTC.lib
#
#  3.15.2003 -- SDB
#
######################################################
# This prog is a simple state machine -- it's activity depends
# upon it's current state.
# States are:
# 0:  Searching for ".SUBCKT".  Write out first line when found.
# 1:  Searching for ".ENDS".  Write out line as long as it is not found;
#     when it is found, abort and return to state 0.

$StateCounter = 0;


while (1) {
#------------------------  State 0 -------------------------
    if ($StateCounter == 0) {   # We are looking for .subckt
        do {
            if (eof(STDIN)) {
                die "EOF found in state 0.  All done. . . . \n";
	    }
	    $Line = <STDIN>;
            
        } until ( ($Line =~ /^.SUBCKT /) || ($Line =~ /^.subckt /) );
	print "Found another .subckt . . .  \n";
        @List = split(/\s+/, $Line);             
        $Subckt = $List[1];         # Extract subckt name from line
	$OutputFilename = $Subckt.".cir";

	open(OUTPUTFILE, ">$OutputFilename");
	print ("$Line");
	print OUTPUTFILE $Line;
	
	$StateCounter = 1;
    }

#------------------------  State 1 -------------------------
    elsif ($StateCounter == 1) { # we are looking for ".ENDS" at beginning of line.
	$Line = <STDIN>;
	if (($Line =~ /^.ENDS /) || ($Line =~ /^.ends /)) {
	    print ("$Line");
	    print OUTPUTFILE $Line;
	    print "\n";
	    $StateCounter = 0;
	    close(OUTPUTFILE);
	}
	else {
	    print ("$Line");
	    print OUTPUTFILE $Line;
	    $StateCounter = 1;
	}
    }
}
